toga-core
=========

The common base for all backends in the `Toga widget toolkit`_.

This package isn't much use by itself; it needs to be combined with
a platform specific backend:

* `toga-cocoa`_: for OS/X
* `toga-gtk`_: GTK+ backend for Linux desktops
* `toga-win32`_: for Windows desktops (limited support)
* `toga-iOS`_: for iOS devices (iPhone, iPad, iPod)
* `toga-android`_: for Android devices (limited support)
* `toga-django`_: for Android devices (limited support)
* `toga-qt`_: Qt backend for (no support)
* `toga-winrt`_: for Windows desktops (no support)

For more details, see the `Toga project on Github`_.

Community
---------

Toga is part of the `BeeWare suite`_. You can talk to the community through:

* `@pybeeware on Twitter`_

* The `BeeWare Users Mailing list`_, for questions about how to use the BeeWare suite.

* The `BeeWare Developers Mailing list`_, for discussing the development of new features in the BeeWare suite, and ideas for new tools for the suite.

Contributing
------------

If you experience problems with this backend, `log them on GitHub`_. If you
want to contribute code, please `fork the code`_ and `submit a pull request`_.

.. _Toga widget toolkit: http://pybee.org/toga
.. _toga-cocoa: http://github.com/pybee/toga-cocoa
.. _toga-gtk: http://github.com/pybee/toga-gtk
.. _toga-win32: http://github.com/pybee/toga-win32
.. _toga-iOS: http://github.com/pybee/toga-iOS
.. _toga-android: http://github.com/pybee/toga-android
.. _toga-django: http://github.com/pybee/toga-django
.. _toga-qt: http://github.com/pybee/toga-qt
.. _toga-winrt: http://github.com/pybee/toga-winrt
.. _Toga project on Github: https://github.com/pybee/toga
.. _BeeWare suite: http://pybee.org
.. _@pybeeware on Twitter: https://twitter.com/pybeeware
.. _BeeWare Users Mailing list: https://groups.google.com/forum/#!forum/beeware-users
.. _BeeWare Developers Mailing list: https://groups.google.com/forum/#!forum/beeware-developers
.. _log them on Github: https://github.com/pybee/toga-cocoa/issues
.. _fork the code: https://github.com/pybee/toga-cocoa
.. _submit a pull request: https://github.com/pybee/toga-cocoa/pulls
